# BoaConstrictor
## Simplicity rocks!
### Why!?!?:
To make a New and Improved coding language.
You see, whenever I look up Python on Reddit, people are always saying
that they wish there was a language which combines the simple syntax of
Python with the simple grammar of C++. Intruiged by the idea, I did a some
looking around to see if such a language exists. Unfortunately, however,
I quickly found that are no such languages. As a result, I decided to make a 
new programming language, which would combine these features. In
addition, I wanted to still be able to use ANY python module in your code. So, 
after several months of work, here is the end product: BoaConstrictor. In
addition, you can use ANY python module in your code.

### Installation using PIP:
``` pip install boaconstrictor ```

### Usage:
``` C:\Users\foo> boaconstrictor Your.File.Here.boa ```
or
``` C:\Users\foo> boaconstrictor Your/File/Here.boa ```

### Example code:
```python
using time
function main(){
    cout "Hello, world!"
    x = 3.5
}
```

If you have any questions, contact me via email. My address is thescribe11@gmail.com.

# CHANGELOG:
V 1.2.2: Fixed escape characters.

V 1.2.3: Fixed problems with the Print and Input functions.

V 1.2.4: Fixed the output filename problem with V 1.2.3.

V 1.2.9: Added ```end``` keyword, fixed the glitch which was causing always to output to 'output.exe'.

V 1.2.10: Fixed ```end``` keyword implementation problem.

V 1.2.11: Got everything up and working, releasing to PyPI.
